# {{project_name }}

{# Template for Python projects
The sections in between these curcly brackets will not be copied in
the template but is a comment to explain how to use the template.
Curly braces are used by jinja2 to inject variable,
e.g. `project_name` above #}

## Introduction

{{ short_description }}
